@@ -133,7 +133,7 @@ Communications Assistance Law Enforcement Act (USA)
 Computer aided Acquisition and Logistics Support
 
 @item CALS
-Continuous Aquisition and Life-cycle Support
+Continuous Acquisition and Life-cycle Support
 
 @item CAM
 Common Access Method (SCSI)
@@ -267,6 +267,9 @@ Computer Aided Software Engineering
 @item CASH
 Computer Aided Service Handling (Ashton-Tate), "C.A.S.H."
 
+@item CASID
+Condition Access System IDentification (DVB, CAT)
+
 @item CAST
 Carlisle Adams and Stafford Tavares (cryptography)
 
@@ -288,6 +291,9 @@ Computer Aided Telephony
 @item CAT
 Computer Aided Testing
 
+@item CAT
+Condition Access Table (DVB)
+
 @item CATI
 Computer Aided Telephone Interviewing
 
@@ -324,6 +330,9 @@ Commercial Beginners All purpose Symbolic Instruction Code (BASIC)
 @item CBC
 Cipher Block Chaining [mode] (DES, DESE, RC5, cryptography)
 
+@item CBCMAC
+Cipher Block Chaining of Message Authentication Code (CBC, MAC, cryptography, WLAN), "CBC-MAC"
+
 @item CBCP
 CallBack Control Protocol
 
@@ -387,6 +396,9 @@ Computerized Branch eXchange (PBX)
 @item CC
 Carbon Copy
 
+@item CC
+Common Criteria [for IT Security Evaluation] (CC)
+
 @item CC
 Continuity Cell (ATM)
 
@@ -474,6 +486,9 @@ CORBA Component Model (CORBA)
 @item CCM
 Counter with CBC-MAC (cryptography, CBC, MAC, RFC 3610)
 
+@item CCMP
+Counter mode CBC MAC Protocol (CBC, MAC, cryptography, WLAN)
+
 @item CCNC
 Common Channel Network Controller
 
@@ -496,7 +511,7 @@ Communications Control Program (OS, IBM)
 Compact Communication Products (TPS)
 
 @item CCPP
-Composite Capability / Prefrence Profiles (W3C, RDF), "CC/PP"
+Composite Capability / Preference Profiles (W3C, RDF), "CC/PP"
 
 @item CCR
 Commitment, Concurrency and Recovery (OSI)
@@ -504,6 +519,9 @@ Commitment, Concurrency and Recovery (OSI)
 @item CCR
 Current Cell Rate (ATM)
 
+@item CCRA
+Common Criteria Recognition Arrangement (CC)
+
 @item CCRMA
 Center for Computer Research in Music and Acoustics (org., Stanford, UK)
 
@@ -712,7 +730,7 @@ Cell Directory Service (DCE)
 Current Directory Structure (BIOS. DOS)
 
 @item CDSA
-Common Data Securuty Architecture (HP, cryptography)
+Common Data Security Architecture (HP, cryptography)
 
 @item CDSG
 Cultural Diversity Steering Group (ISSS)
@@ -804,6 +822,9 @@ Card Edge Low Profile [socket]
 @item CELP
 Code Excited Linear Prediction
 
+@item CEM
+Common [IT Security] Evaluation Methodology (CC)
+
 @item CEM
 Contract Equipment Manufacturer
 
@@ -877,7 +898,7 @@ Compact Framework (MS, .NET, PocketPC)
 Center for Architecture (org., JIEO, DISA)
 
 @item CFA
-Code Fiels Address (Forth)
+Code Fields Address (Forth)
 
 @item CFB
 Cipher FeedBack [mode] (cryptography, DES)
@@ -933,6 +954,9 @@ Cryptographic FileSystem (Linux, cryptography)
 @item CFV
 Call For Vote (Internet, Usenet), "CfV"
 
+@item CFWS
+Comments / Folding White Space (RFC 1822)
+
 @item CGA
 Colour Graphics Adapter
 
@@ -1740,6 +1764,9 @@ Central Office Terminal
 @item COTP
 Connection-Oriented Transport Protocol (OSI, ISO 8073)
 
+@item COTS
+Commercial Off The Shelf (CC)
+
 @item COTS
 Connection-Oriented Transport [layer] Service
 
@@ -1918,7 +1945,7 @@ Cable Repair Administrative System
 Cyclic Redundancy Check[sum]
 
 @item CRCG
-[fraunhofer] Center for Research in Computer Graphics (org., USA)
+[Fraunhofer] Center for Research in Computer Graphics (org., USA)
 
 @item CRCG
 Common Routing Connection Group
