@@ -145,7 +145,7 @@ Frame Burst error Length (CD)
 Flexible Buffer Management (QMS)
 
 @item FBPP
-Federal Biomteric Protection Profile (NIAP)
+Federal Biometeric Protection Profile (NIAP)
 
 @item FBS
 Flexible Bandwidth Service (ATM, SDH)
@@ -178,7 +178,7 @@ File Control Block (DOS)
 File Control BlockS (DOS)
 
 @item FCC
-Fast Communication Controler (SCC, MCC)
+Fast Communication Controller (SCC, MCC)
 
 @item FCC
 Federal Communications Commission (org., USA)
@@ -702,6 +702,9 @@ Fiber Optic Transceiver
 @item FOTE
 Follow-on Operational Test and Evaluation, "FOT & E"
 
+@item FOUC
+Flash Of Unstyled Content (CSS)
+
 @item FOURCC
 FOUR Character Code (RIFF, TIFF, VFW, DivX)
 
@@ -795,6 +798,9 @@ Floating Point Register (FPU)
 @item FPS
 Fast Packet Switching (X.25, Datex-J)
 
+@item FPS
+First Person Shooter [game]
+
 @item FPS
 Frames Per Second
 
@@ -1029,6 +1035,9 @@ FirmWare Hub (BIOS, Intel)
 @item FWIW
 For What It's Worth (slang, Usenet, IRC)
 
+@item FWS
+Folding White Space (RFC 1822)
+
 @item FWT
 Fast Wavelet Transformation
 
