@@ -24,6 +24,9 @@ Host Access Class Library (HOD, API)
 @item HACMP
 High Availability Clustered Multi Processing (IBM, RS/6000, Bull), "HA/CMP"
 
+@item HADR
+High Availability Disaster Recovery (Informix, DB2, DB)
+
 @item HAL
 Hard Array Logic
 
@@ -331,7 +334,7 @@ High Performance Peripheral Interface
 HURD of Interfaces Representing Depth (GNU, HURD)
 
 @item HISAM
-Hierarchical Indexed Sequential Acess Method (SAM)
+Hierarchical Indexed Sequential Access Method (SAM)
 
 @item HISP
 HIgh SPeed channel connector (Cray, I/O)
@@ -450,6 +453,9 @@ High Performance Communication Server (Tobit, NLM, Netware)
 @item HPCS
 High Productivity Computing System (DARPA, Cray, IBM, Sun, ...)
 
+@item HPET
+High Precision Event Timer (IC, Intel, MS)
+
 @item HPF
 High Performance FORTRAN (FORTRAN)
 
@@ -489,6 +495,12 @@ High Priority Request (VUMA)
 @item HPRILOE
 ??? - Remote Insight Lights-Out Edition, "HP-RILOE"
 
+@item HPS
+Hardware Product Services
+
+@item HPS
+High Performance Switch (IBM)
+
 @item HPTS
 High Performance Transaction Systems
 
