@@ -430,7 +430,7 @@ MultiDimensional DataBase (DB)
 Mobile DatenErfassung, "mDE"
 
 @item MDEF
-Menu DEfinintion Functions (Apple, CDEF)
+Menu DEfinition Functions (Apple, CDEF)
 
 @item MDI
 Medium Dependent Interface (ethernet)
@@ -1224,6 +1224,9 @@ MultiPlatform DiskArray
 @item MPDU
 Message Protocol Data Unit (PDU)
 
+@item MPE
+Multi Protocol Encapsulation (DVB)
+
 @item MPE
 Multi-Programming Executive (OS, HP, HP 3000)
 
