@@ -154,7 +154,7 @@ Random Block Filemanager (OS-9)
 Remote Bridge Hub
 
 @item RBL
-Realtime Blackhole List (Internet, SPAM)
+Realtime Blackhole / Block List (Internet, SPAM)
 
 @item RBM
 Realtime Batch Monitor (OS, Xerox)
@@ -351,14 +351,11 @@ Relative Distinguished Name (X.500)
 @item RDNCRC
 Research Data Network Cooperative Research Centre (org., Australia)
 
-@item RDO
-??? (CICS, IBM)
-
 @item RDO
 Remote Data Objects (DB)
 
 @item RDO
-Resouce Definition Online (CICS, IBM)
+Resource Definition Online (CICS, IBM)
 
 @item RDP
 Reliable Datagram Protocol
@@ -432,6 +429,9 @@ Real Estate Management Information System
 @item REMOS
 Resources Management On-Line System
 
+@item REPL
+Read Eval Print Loop
+
 @item RES
 Remote Entry Services
 
@@ -516,6 +516,9 @@ Remote File Sharing (AT&T, Unix)
 @item RFS
 Remote File System
 
+@item RFS
+Request For Sponsor (Linux, Debian)
+
 @item RFS
 REXX File System (REXX, CICS, VSAM, IBM)
 
@@ -1110,6 +1113,9 @@ Remote Switching Module
 @item RSN
 Real Soon Now (slang)
 
+@item RSN
+Robust Security Network (WLAN, cryptography)
+
 @item RSP
 Reality Signal Processor (Nintendo)
 
@@ -1122,6 +1128,9 @@ Rich / RDF Site Summary (XML, RDF)
 @item RSSCP
 Remote System Services Control Point (SSCP)
 
+@item RST
+Running Status Table (DVB)
+
 @item RSTS
 Resource Sharing Time Sharing (DEC)
 
